(v0.11.0rc2)=
### 0.11.0rc2 {small}`2024-09-24`

### Development Process

- Add extra `dask` dependency for installation i.e., `pip install anndata[dask]` {user}`ilan-gold` ({pr}`1677`)
- Remove `shall_` from variable names in `settings` {user}`ilan-gold` ({pr}`1685`)
